inline void DecryptBuf::eoi()
{}
